from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Geolocation
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Services.Maps
import win32more.Windows.Services.Maps.Guidance
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class GuidanceAudioMeasurementSystem(Enum, Int32):
    Meters = 0
    MilesAndYards = 1
    MilesAndFeet = 2
class GuidanceAudioNotificationKind(Enum, Int32):
    Maneuver = 0
    Route = 1
    Gps = 2
    SpeedLimit = 3
    Traffic = 4
    TrafficCamera = 5
class GuidanceAudioNotificationRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceAudioNotificationRequestedEventArgs
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceAudioNotificationRequestedEventArgs'
    @winrt_mixinmethod
    def get_AudioNotification(self: win32more.Windows.Services.Maps.Guidance.IGuidanceAudioNotificationRequestedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotificationKind: ...
    @winrt_mixinmethod
    def get_AudioFilePaths(self: win32more.Windows.Services.Maps.Guidance.IGuidanceAudioNotificationRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_AudioText(self: win32more.Windows.Services.Maps.Guidance.IGuidanceAudioNotificationRequestedEventArgs) -> WinRT_String: ...
    AudioFilePaths = property(get_AudioFilePaths, None)
    AudioNotification = property(get_AudioNotification, None)
    AudioText = property(get_AudioText, None)
class GuidanceAudioNotifications(Enum, UInt32):
    None_ = 0
    Maneuver = 1
    Route = 2
    Gps = 4
    SpeedLimit = 8
    Traffic = 16
    TrafficCamera = 32
class GuidanceLaneInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceLaneInfo
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceLaneInfo'
    @winrt_mixinmethod
    def get_LaneMarkers(self: win32more.Windows.Services.Maps.Guidance.IGuidanceLaneInfo) -> win32more.Windows.Services.Maps.Guidance.GuidanceLaneMarkers: ...
    @winrt_mixinmethod
    def get_IsOnRoute(self: win32more.Windows.Services.Maps.Guidance.IGuidanceLaneInfo) -> Boolean: ...
    IsOnRoute = property(get_IsOnRoute, None)
    LaneMarkers = property(get_LaneMarkers, None)
class GuidanceLaneMarkers(Enum, UInt32):
    None_ = 0
    LightRight = 1
    Right = 2
    HardRight = 4
    Straight = 8
    UTurnLeft = 16
    HardLeft = 32
    Left = 64
    LightLeft = 128
    UTurnRight = 256
    Unknown = 4294967295
class GuidanceManeuver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceManeuver'
    @winrt_mixinmethod
    def get_StartLocation(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_mixinmethod
    def get_DistanceFromRouteStart(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> Int32: ...
    @winrt_mixinmethod
    def get_DistanceFromPreviousManeuver(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> Int32: ...
    @winrt_mixinmethod
    def get_DepartureRoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NextRoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DepartureShortRoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NextShortRoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuverKind: ...
    @winrt_mixinmethod
    def get_StartAngle(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> Int32: ...
    @winrt_mixinmethod
    def get_EndAngle(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> Int32: ...
    @winrt_mixinmethod
    def get_RoadSignpost(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoadSignpost: ...
    @winrt_mixinmethod
    def get_InstructionText(self: win32more.Windows.Services.Maps.Guidance.IGuidanceManeuver) -> WinRT_String: ...
    DepartureRoadName = property(get_DepartureRoadName, None)
    DepartureShortRoadName = property(get_DepartureShortRoadName, None)
    DistanceFromPreviousManeuver = property(get_DistanceFromPreviousManeuver, None)
    DistanceFromRouteStart = property(get_DistanceFromRouteStart, None)
    EndAngle = property(get_EndAngle, None)
    InstructionText = property(get_InstructionText, None)
    Kind = property(get_Kind, None)
    NextRoadName = property(get_NextRoadName, None)
    NextShortRoadName = property(get_NextShortRoadName, None)
    RoadSignpost = property(get_RoadSignpost, None)
    StartAngle = property(get_StartAngle, None)
    StartLocation = property(get_StartLocation, None)
class GuidanceManeuverKind(Enum, Int32):
    None_ = 0
    GoStraight = 1
    UTurnRight = 2
    UTurnLeft = 3
    TurnKeepRight = 4
    TurnLightRight = 5
    TurnRight = 6
    TurnHardRight = 7
    KeepMiddle = 8
    TurnKeepLeft = 9
    TurnLightLeft = 10
    TurnLeft = 11
    TurnHardLeft = 12
    FreewayEnterRight = 13
    FreewayEnterLeft = 14
    FreewayLeaveRight = 15
    FreewayLeaveLeft = 16
    FreewayKeepRight = 17
    FreewayKeepLeft = 18
    TrafficCircleRight1 = 19
    TrafficCircleRight2 = 20
    TrafficCircleRight3 = 21
    TrafficCircleRight4 = 22
    TrafficCircleRight5 = 23
    TrafficCircleRight6 = 24
    TrafficCircleRight7 = 25
    TrafficCircleRight8 = 26
    TrafficCircleRight9 = 27
    TrafficCircleRight10 = 28
    TrafficCircleRight11 = 29
    TrafficCircleRight12 = 30
    TrafficCircleLeft1 = 31
    TrafficCircleLeft2 = 32
    TrafficCircleLeft3 = 33
    TrafficCircleLeft4 = 34
    TrafficCircleLeft5 = 35
    TrafficCircleLeft6 = 36
    TrafficCircleLeft7 = 37
    TrafficCircleLeft8 = 38
    TrafficCircleLeft9 = 39
    TrafficCircleLeft10 = 40
    TrafficCircleLeft11 = 41
    TrafficCircleLeft12 = 42
    Start = 43
    End = 44
    TakeFerry = 45
    PassTransitStation = 46
    LeaveTransitStation = 47
class GuidanceMapMatchedCoordinate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceMapMatchedCoordinate'
    @winrt_mixinmethod
    def get_Location(self: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_mixinmethod
    def get_CurrentHeading(self: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate) -> Double: ...
    @winrt_mixinmethod
    def get_CurrentSpeed(self: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate) -> Double: ...
    @winrt_mixinmethod
    def get_IsOnStreet(self: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate) -> Boolean: ...
    @winrt_mixinmethod
    def get_Road(self: win32more.Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoadSegment: ...
    CurrentHeading = property(get_CurrentHeading, None)
    CurrentSpeed = property(get_CurrentSpeed, None)
    IsOnStreet = property(get_IsOnStreet, None)
    Location = property(get_Location, None)
    Road = property(get_Road, None)
class GuidanceMode(Enum, Int32):
    None_ = 0
    Simulation = 1
    Navigation = 2
    Tracking = 3
class _GuidanceNavigator_Meta_(ComPtr.__class__):
    pass
class GuidanceNavigator(ComPtr, metaclass=_GuidanceNavigator_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceNavigator'
    @winrt_mixinmethod
    def StartNavigating(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, route: win32more.Windows.Services.Maps.Guidance.GuidanceRoute) -> Void: ...
    @winrt_mixinmethod
    def StartSimulating(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, route: win32more.Windows.Services.Maps.Guidance.GuidanceRoute, speedInMetersPerSecond: Int32) -> Void: ...
    @winrt_mixinmethod
    def StartTracking(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> Void: ...
    @winrt_mixinmethod
    def Pause(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> Void: ...
    @winrt_mixinmethod
    def Resume(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> Void: ...
    @winrt_mixinmethod
    def RepeatLastAudioNotification(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> Void: ...
    @winrt_mixinmethod
    def get_AudioMeasurementSystem(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioMeasurementSystem: ...
    @winrt_mixinmethod
    def put_AudioMeasurementSystem(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, value: win32more.Windows.Services.Maps.Guidance.GuidanceAudioMeasurementSystem) -> Void: ...
    @winrt_mixinmethod
    def get_AudioNotifications(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotifications: ...
    @winrt_mixinmethod
    def put_AudioNotifications(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, value: win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotifications) -> Void: ...
    @winrt_mixinmethod
    def add_GuidanceUpdated(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceUpdatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GuidanceUpdated(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DestinationReached(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DestinationReached(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Rerouting(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Rerouting(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Rerouted(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceReroutedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Rerouted(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_RerouteFailed(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RerouteFailed(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserLocationLost(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserLocationLost(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserLocationRestored(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserLocationRestored(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetGuidanceVoice(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, voiceId: Int32, voiceFolder: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def UpdateUserLocation(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, userLocation: win32more.Windows.Devices.Geolocation.Geocoordinate) -> Void: ...
    @winrt_mixinmethod
    def UpdateUserLocationWithPositionOverride(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator, userLocation: win32more.Windows.Devices.Geolocation.Geocoordinate, positionOverride: win32more.Windows.Devices.Geolocation.BasicGeoposition) -> Void: ...
    @winrt_mixinmethod
    def add_AudioNotificationRequested(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator2, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotificationRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AudioNotificationRequested(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IsGuidanceAudioMuted(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGuidanceAudioMuted(self: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigator2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UseAppProvidedVoice(cls: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigatorStatics2) -> Boolean: ...
    @winrt_classmethod
    def GetCurrent(cls: win32more.Windows.Services.Maps.Guidance.IGuidanceNavigatorStatics) -> win32more.Windows.Services.Maps.Guidance.GuidanceNavigator: ...
    AudioMeasurementSystem = property(get_AudioMeasurementSystem, put_AudioMeasurementSystem)
    AudioNotifications = property(get_AudioNotifications, put_AudioNotifications)
    IsGuidanceAudioMuted = property(get_IsGuidanceAudioMuted, put_IsGuidanceAudioMuted)
    _GuidanceNavigator_Meta_.UseAppProvidedVoice = property(get_UseAppProvidedVoice, None)
    GuidanceUpdated = event()
    DestinationReached = event()
    Rerouting = event()
    Rerouted = event()
    RerouteFailed = event()
    UserLocationLost = event()
    UserLocationRestored = event()
    AudioNotificationRequested = event()
class GuidanceReroutedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceReroutedEventArgs
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceReroutedEventArgs'
    @winrt_mixinmethod
    def get_Route(self: win32more.Windows.Services.Maps.Guidance.IGuidanceReroutedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
    Route = property(get_Route, None)
class GuidanceRoadSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceRoadSegment'
    @winrt_mixinmethod
    def get_RoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ShortRoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SpeedLimit(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> Double: ...
    @winrt_mixinmethod
    def get_TravelTime(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> win32more.Windows.Devices.Geolocation.Geopath: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsHighway(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsTunnel(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsTollRoad(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsScenic(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSegment2) -> Boolean: ...
    Id = property(get_Id, None)
    IsHighway = property(get_IsHighway, None)
    IsScenic = property(get_IsScenic, None)
    IsTollRoad = property(get_IsTollRoad, None)
    IsTunnel = property(get_IsTunnel, None)
    Path = property(get_Path, None)
    RoadName = property(get_RoadName, None)
    ShortRoadName = property(get_ShortRoadName, None)
    SpeedLimit = property(get_SpeedLimit, None)
    TravelTime = property(get_TravelTime, None)
class GuidanceRoadSignpost(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceRoadSignpost'
    @winrt_mixinmethod
    def get_ExitNumber(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Exit(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_BackgroundColor(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def get_ForegroundColor(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def get_ExitDirections(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoadSignpost) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    BackgroundColor = property(get_BackgroundColor, None)
    Exit = property(get_Exit, None)
    ExitDirections = property(get_ExitDirections, None)
    ExitNumber = property(get_ExitNumber, None)
    ForegroundColor = property(get_ForegroundColor, None)
class GuidanceRoute(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceRoute'
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Distance(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> Int32: ...
    @winrt_mixinmethod
    def get_Maneuvers(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceManeuver]: ...
    @winrt_mixinmethod
    def get_BoundingBox(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Devices.Geolocation.GeoboundingBox: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Devices.Geolocation.Geopath: ...
    @winrt_mixinmethod
    def get_RoadSegments(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceRoadSegment]: ...
    @winrt_mixinmethod
    def ConvertToMapRoute(self: win32more.Windows.Services.Maps.Guidance.IGuidanceRoute) -> win32more.Windows.Services.Maps.MapRoute: ...
    @winrt_classmethod
    def CanCreateFromMapRoute(cls: win32more.Windows.Services.Maps.Guidance.IGuidanceRouteStatics, mapRoute: win32more.Windows.Services.Maps.MapRoute) -> Boolean: ...
    @winrt_classmethod
    def TryCreateFromMapRoute(cls: win32more.Windows.Services.Maps.Guidance.IGuidanceRouteStatics, mapRoute: win32more.Windows.Services.Maps.MapRoute) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
    BoundingBox = property(get_BoundingBox, None)
    Distance = property(get_Distance, None)
    Duration = property(get_Duration, None)
    Maneuvers = property(get_Maneuvers, None)
    Path = property(get_Path, None)
    RoadSegments = property(get_RoadSegments, None)
class GuidanceTelemetryCollector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceTelemetryCollector'
    @winrt_mixinmethod
    def get_Enabled(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector) -> Boolean: ...
    @winrt_mixinmethod
    def put_Enabled(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def ClearLocalData(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector) -> Void: ...
    @winrt_mixinmethod
    def get_SpeedTrigger(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector) -> Double: ...
    @winrt_mixinmethod
    def put_SpeedTrigger(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_UploadFrequency(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector) -> Int32: ...
    @winrt_mixinmethod
    def put_UploadFrequency(self: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector, value: Int32) -> Void: ...
    @winrt_classmethod
    def GetCurrent(cls: win32more.Windows.Services.Maps.Guidance.IGuidanceTelemetryCollectorStatics) -> win32more.Windows.Services.Maps.Guidance.GuidanceTelemetryCollector: ...
    Enabled = property(get_Enabled, put_Enabled)
    SpeedTrigger = property(get_SpeedTrigger, put_SpeedTrigger)
    UploadFrequency = property(get_UploadFrequency, put_UploadFrequency)
class GuidanceUpdatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs
    _classid_ = 'Windows.Services.Maps.Guidance.GuidanceUpdatedEventArgs'
    @winrt_mixinmethod
    def get_Mode(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceMode: ...
    @winrt_mixinmethod
    def get_NextManeuver(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuver: ...
    @winrt_mixinmethod
    def get_NextManeuverDistance(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_AfterNextManeuver(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuver: ...
    @winrt_mixinmethod
    def get_AfterNextManeuverDistance(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_DistanceToDestination(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_ElapsedDistance(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_ElapsedTime(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_TimeToDestination(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_RoadName(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Route(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
    @winrt_mixinmethod
    def get_CurrentLocation(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Services.Maps.Guidance.GuidanceMapMatchedCoordinate: ...
    @winrt_mixinmethod
    def get_IsNewManeuver(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_LaneInfo(self: win32more.Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceLaneInfo]: ...
    AfterNextManeuver = property(get_AfterNextManeuver, None)
    AfterNextManeuverDistance = property(get_AfterNextManeuverDistance, None)
    CurrentLocation = property(get_CurrentLocation, None)
    DistanceToDestination = property(get_DistanceToDestination, None)
    ElapsedDistance = property(get_ElapsedDistance, None)
    ElapsedTime = property(get_ElapsedTime, None)
    IsNewManeuver = property(get_IsNewManeuver, None)
    LaneInfo = property(get_LaneInfo, None)
    Mode = property(get_Mode, None)
    NextManeuver = property(get_NextManeuver, None)
    NextManeuverDistance = property(get_NextManeuverDistance, None)
    RoadName = property(get_RoadName, None)
    Route = property(get_Route, None)
    TimeToDestination = property(get_TimeToDestination, None)
class IGuidanceAudioNotificationRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceAudioNotificationRequestedEventArgs'
    _iid_ = Guid('{ca2aa24a-c7c2-4d4c-9d7c-499576bceddb}')
    @winrt_commethod(6)
    def get_AudioNotification(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotificationKind: ...
    @winrt_commethod(7)
    def get_AudioFilePaths(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(8)
    def get_AudioText(self) -> WinRT_String: ...
    AudioFilePaths = property(get_AudioFilePaths, None)
    AudioNotification = property(get_AudioNotification, None)
    AudioText = property(get_AudioText, None)
class IGuidanceLaneInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceLaneInfo'
    _iid_ = Guid('{8404d114-6581-43b7-ac15-c9079bf90df1}')
    @winrt_commethod(6)
    def get_LaneMarkers(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceLaneMarkers: ...
    @winrt_commethod(7)
    def get_IsOnRoute(self) -> Boolean: ...
    IsOnRoute = property(get_IsOnRoute, None)
    LaneMarkers = property(get_LaneMarkers, None)
class IGuidanceManeuver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceManeuver'
    _iid_ = Guid('{fc09326c-ecc9-4928-a2a1-7232b99b94a1}')
    @winrt_commethod(6)
    def get_StartLocation(self) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_commethod(7)
    def get_DistanceFromRouteStart(self) -> Int32: ...
    @winrt_commethod(8)
    def get_DistanceFromPreviousManeuver(self) -> Int32: ...
    @winrt_commethod(9)
    def get_DepartureRoadName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_NextRoadName(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_DepartureShortRoadName(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_NextShortRoadName(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_Kind(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuverKind: ...
    @winrt_commethod(14)
    def get_StartAngle(self) -> Int32: ...
    @winrt_commethod(15)
    def get_EndAngle(self) -> Int32: ...
    @winrt_commethod(16)
    def get_RoadSignpost(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoadSignpost: ...
    @winrt_commethod(17)
    def get_InstructionText(self) -> WinRT_String: ...
    DepartureRoadName = property(get_DepartureRoadName, None)
    DepartureShortRoadName = property(get_DepartureShortRoadName, None)
    DistanceFromPreviousManeuver = property(get_DistanceFromPreviousManeuver, None)
    DistanceFromRouteStart = property(get_DistanceFromRouteStart, None)
    EndAngle = property(get_EndAngle, None)
    InstructionText = property(get_InstructionText, None)
    Kind = property(get_Kind, None)
    NextRoadName = property(get_NextRoadName, None)
    NextShortRoadName = property(get_NextShortRoadName, None)
    RoadSignpost = property(get_RoadSignpost, None)
    StartAngle = property(get_StartAngle, None)
    StartLocation = property(get_StartLocation, None)
class IGuidanceMapMatchedCoordinate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceMapMatchedCoordinate'
    _iid_ = Guid('{b7acb168-2912-4a99-aff1-798609b981fe}')
    @winrt_commethod(6)
    def get_Location(self) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_commethod(7)
    def get_CurrentHeading(self) -> Double: ...
    @winrt_commethod(8)
    def get_CurrentSpeed(self) -> Double: ...
    @winrt_commethod(9)
    def get_IsOnStreet(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_Road(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoadSegment: ...
    CurrentHeading = property(get_CurrentHeading, None)
    CurrentSpeed = property(get_CurrentSpeed, None)
    IsOnStreet = property(get_IsOnStreet, None)
    Location = property(get_Location, None)
    Road = property(get_Road, None)
class IGuidanceNavigator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceNavigator'
    _iid_ = Guid('{08f17ef7-8e3f-4d9a-be8a-108f9a012c67}')
    @winrt_commethod(6)
    def StartNavigating(self, route: win32more.Windows.Services.Maps.Guidance.GuidanceRoute) -> Void: ...
    @winrt_commethod(7)
    def StartSimulating(self, route: win32more.Windows.Services.Maps.Guidance.GuidanceRoute, speedInMetersPerSecond: Int32) -> Void: ...
    @winrt_commethod(8)
    def StartTracking(self) -> Void: ...
    @winrt_commethod(9)
    def Pause(self) -> Void: ...
    @winrt_commethod(10)
    def Resume(self) -> Void: ...
    @winrt_commethod(11)
    def Stop(self) -> Void: ...
    @winrt_commethod(12)
    def RepeatLastAudioNotification(self) -> Void: ...
    @winrt_commethod(13)
    def get_AudioMeasurementSystem(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioMeasurementSystem: ...
    @winrt_commethod(14)
    def put_AudioMeasurementSystem(self, value: win32more.Windows.Services.Maps.Guidance.GuidanceAudioMeasurementSystem) -> Void: ...
    @winrt_commethod(15)
    def get_AudioNotifications(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotifications: ...
    @winrt_commethod(16)
    def put_AudioNotifications(self, value: win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotifications) -> Void: ...
    @winrt_commethod(17)
    def add_GuidanceUpdated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceUpdatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_GuidanceUpdated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_DestinationReached(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_DestinationReached(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def add_Rerouting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_Rerouting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(23)
    def add_Rerouted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceReroutedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_Rerouted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def add_RerouteFailed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_RerouteFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(27)
    def add_UserLocationLost(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(28)
    def remove_UserLocationLost(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(29)
    def add_UserLocationRestored(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(30)
    def remove_UserLocationRestored(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(31)
    def SetGuidanceVoice(self, voiceId: Int32, voiceFolder: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def UpdateUserLocation(self, userLocation: win32more.Windows.Devices.Geolocation.Geocoordinate) -> Void: ...
    @winrt_commethod(33)
    def UpdateUserLocationWithPositionOverride(self, userLocation: win32more.Windows.Devices.Geolocation.Geocoordinate, positionOverride: win32more.Windows.Devices.Geolocation.BasicGeoposition) -> Void: ...
    AudioMeasurementSystem = property(get_AudioMeasurementSystem, put_AudioMeasurementSystem)
    AudioNotifications = property(get_AudioNotifications, put_AudioNotifications)
    GuidanceUpdated = event()
    DestinationReached = event()
    Rerouting = event()
    Rerouted = event()
    RerouteFailed = event()
    UserLocationLost = event()
    UserLocationRestored = event()
class IGuidanceNavigator2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceNavigator2'
    _iid_ = Guid('{6cdc50d1-041c-4bf3-b633-a101fc2f6b57}')
    @winrt_commethod(6)
    def add_AudioNotificationRequested(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Services.Maps.Guidance.GuidanceNavigator, win32more.Windows.Services.Maps.Guidance.GuidanceAudioNotificationRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_AudioNotificationRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def get_IsGuidanceAudioMuted(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsGuidanceAudioMuted(self, value: Boolean) -> Void: ...
    IsGuidanceAudioMuted = property(get_IsGuidanceAudioMuted, put_IsGuidanceAudioMuted)
    AudioNotificationRequested = event()
class IGuidanceNavigatorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceNavigatorStatics'
    _iid_ = Guid('{00fd9513-4456-4e66-a143-3add6be08426}')
    @winrt_commethod(6)
    def GetCurrent(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceNavigator: ...
class IGuidanceNavigatorStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceNavigatorStatics2'
    _iid_ = Guid('{54c5c3e2-7784-4c85-8c95-d0c6efb43965}')
    @winrt_commethod(6)
    def get_UseAppProvidedVoice(self) -> Boolean: ...
    UseAppProvidedVoice = property(get_UseAppProvidedVoice, None)
class IGuidanceReroutedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceReroutedEventArgs'
    _iid_ = Guid('{115d4008-d528-454e-bb94-a50341d2c9f1}')
    @winrt_commethod(6)
    def get_Route(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
    Route = property(get_Route, None)
class IGuidanceRoadSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceRoadSegment'
    _iid_ = Guid('{b32758a6-be78-4c63-afe7-6c2957479b3e}')
    @winrt_commethod(6)
    def get_RoadName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ShortRoadName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SpeedLimit(self) -> Double: ...
    @winrt_commethod(9)
    def get_TravelTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(10)
    def get_Path(self) -> win32more.Windows.Devices.Geolocation.Geopath: ...
    @winrt_commethod(11)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_IsHighway(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsTunnel(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_IsTollRoad(self) -> Boolean: ...
    Id = property(get_Id, None)
    IsHighway = property(get_IsHighway, None)
    IsTollRoad = property(get_IsTollRoad, None)
    IsTunnel = property(get_IsTunnel, None)
    Path = property(get_Path, None)
    RoadName = property(get_RoadName, None)
    ShortRoadName = property(get_ShortRoadName, None)
    SpeedLimit = property(get_SpeedLimit, None)
    TravelTime = property(get_TravelTime, None)
class IGuidanceRoadSegment2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceRoadSegment2'
    _iid_ = Guid('{2474a61d-1723-49f1-895b-47a2c4aa9c55}')
    @winrt_commethod(6)
    def get_IsScenic(self) -> Boolean: ...
    IsScenic = property(get_IsScenic, None)
class IGuidanceRoadSignpost(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceRoadSignpost'
    _iid_ = Guid('{f1a728b6-f77a-4742-8312-53300f9845f0}')
    @winrt_commethod(6)
    def get_ExitNumber(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Exit(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_BackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def get_ForegroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(10)
    def get_ExitDirections(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    BackgroundColor = property(get_BackgroundColor, None)
    Exit = property(get_Exit, None)
    ExitDirections = property(get_ExitDirections, None)
    ExitNumber = property(get_ExitNumber, None)
    ForegroundColor = property(get_ForegroundColor, None)
class IGuidanceRoute(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceRoute'
    _iid_ = Guid('{3a14545d-801a-40bd-a286-afb2010cce6c}')
    @winrt_commethod(6)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_Distance(self) -> Int32: ...
    @winrt_commethod(8)
    def get_Maneuvers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceManeuver]: ...
    @winrt_commethod(9)
    def get_BoundingBox(self) -> win32more.Windows.Devices.Geolocation.GeoboundingBox: ...
    @winrt_commethod(10)
    def get_Path(self) -> win32more.Windows.Devices.Geolocation.Geopath: ...
    @winrt_commethod(11)
    def get_RoadSegments(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceRoadSegment]: ...
    @winrt_commethod(12)
    def ConvertToMapRoute(self) -> win32more.Windows.Services.Maps.MapRoute: ...
    BoundingBox = property(get_BoundingBox, None)
    Distance = property(get_Distance, None)
    Duration = property(get_Duration, None)
    Maneuvers = property(get_Maneuvers, None)
    Path = property(get_Path, None)
    RoadSegments = property(get_RoadSegments, None)
class IGuidanceRouteStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceRouteStatics'
    _iid_ = Guid('{f56d926a-55ed-49c1-b09c-4b8223b50db3}')
    @winrt_commethod(6)
    def CanCreateFromMapRoute(self, mapRoute: win32more.Windows.Services.Maps.MapRoute) -> Boolean: ...
    @winrt_commethod(7)
    def TryCreateFromMapRoute(self, mapRoute: win32more.Windows.Services.Maps.MapRoute) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
class IGuidanceTelemetryCollector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceTelemetryCollector'
    _iid_ = Guid('{db1f8da5-b878-4d92-98dd-347d23d38262}')
    @winrt_commethod(6)
    def get_Enabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Enabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def ClearLocalData(self) -> Void: ...
    @winrt_commethod(9)
    def get_SpeedTrigger(self) -> Double: ...
    @winrt_commethod(10)
    def put_SpeedTrigger(self, value: Double) -> Void: ...
    @winrt_commethod(11)
    def get_UploadFrequency(self) -> Int32: ...
    @winrt_commethod(12)
    def put_UploadFrequency(self, value: Int32) -> Void: ...
    Enabled = property(get_Enabled, put_Enabled)
    SpeedTrigger = property(get_SpeedTrigger, put_SpeedTrigger)
    UploadFrequency = property(get_UploadFrequency, put_UploadFrequency)
class IGuidanceTelemetryCollectorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceTelemetryCollectorStatics'
    _iid_ = Guid('{36532047-f160-44fb-b578-94577ca05990}')
    @winrt_commethod(6)
    def GetCurrent(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceTelemetryCollector: ...
class IGuidanceUpdatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Maps.Guidance.IGuidanceUpdatedEventArgs'
    _iid_ = Guid('{fdac160b-9e8d-4de3-a9fa-b06321d18db9}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceMode: ...
    @winrt_commethod(7)
    def get_NextManeuver(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuver: ...
    @winrt_commethod(8)
    def get_NextManeuverDistance(self) -> Int32: ...
    @winrt_commethod(9)
    def get_AfterNextManeuver(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceManeuver: ...
    @winrt_commethod(10)
    def get_AfterNextManeuverDistance(self) -> Int32: ...
    @winrt_commethod(11)
    def get_DistanceToDestination(self) -> Int32: ...
    @winrt_commethod(12)
    def get_ElapsedDistance(self) -> Int32: ...
    @winrt_commethod(13)
    def get_ElapsedTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(14)
    def get_TimeToDestination(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(15)
    def get_RoadName(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def get_Route(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceRoute: ...
    @winrt_commethod(17)
    def get_CurrentLocation(self) -> win32more.Windows.Services.Maps.Guidance.GuidanceMapMatchedCoordinate: ...
    @winrt_commethod(18)
    def get_IsNewManeuver(self) -> Boolean: ...
    @winrt_commethod(19)
    def get_LaneInfo(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Services.Maps.Guidance.GuidanceLaneInfo]: ...
    AfterNextManeuver = property(get_AfterNextManeuver, None)
    AfterNextManeuverDistance = property(get_AfterNextManeuverDistance, None)
    CurrentLocation = property(get_CurrentLocation, None)
    DistanceToDestination = property(get_DistanceToDestination, None)
    ElapsedDistance = property(get_ElapsedDistance, None)
    ElapsedTime = property(get_ElapsedTime, None)
    IsNewManeuver = property(get_IsNewManeuver, None)
    LaneInfo = property(get_LaneInfo, None)
    Mode = property(get_Mode, None)
    NextManeuver = property(get_NextManeuver, None)
    NextManeuverDistance = property(get_NextManeuverDistance, None)
    RoadName = property(get_RoadName, None)
    Route = property(get_Route, None)
    TimeToDestination = property(get_TimeToDestination, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.Input
import win32more.Windows.UI.Input.Preview.Injection
import win32more.Windows.Win32.System.WinRT
class IInjectedInputGamepadInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo'
    _iid_ = Guid('{20ae9a3f-df11-4572-a9ab-d75b8a5e48ad}')
    @winrt_commethod(6)
    def get_Buttons(self) -> win32more.Windows.Gaming.Input.GamepadButtons: ...
    @winrt_commethod(7)
    def put_Buttons(self, value: win32more.Windows.Gaming.Input.GamepadButtons) -> Void: ...
    @winrt_commethod(8)
    def get_LeftThumbstickX(self) -> Double: ...
    @winrt_commethod(9)
    def put_LeftThumbstickX(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_LeftThumbstickY(self) -> Double: ...
    @winrt_commethod(11)
    def put_LeftThumbstickY(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_LeftTrigger(self) -> Double: ...
    @winrt_commethod(13)
    def put_LeftTrigger(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_RightThumbstickX(self) -> Double: ...
    @winrt_commethod(15)
    def put_RightThumbstickX(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_RightThumbstickY(self) -> Double: ...
    @winrt_commethod(17)
    def put_RightThumbstickY(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_RightTrigger(self) -> Double: ...
    @winrt_commethod(19)
    def put_RightTrigger(self, value: Double) -> Void: ...
    Buttons = property(get_Buttons, put_Buttons)
    LeftThumbstickX = property(get_LeftThumbstickX, put_LeftThumbstickX)
    LeftThumbstickY = property(get_LeftThumbstickY, put_LeftThumbstickY)
    LeftTrigger = property(get_LeftTrigger, put_LeftTrigger)
    RightThumbstickX = property(get_RightThumbstickX, put_RightThumbstickX)
    RightThumbstickY = property(get_RightThumbstickY, put_RightThumbstickY)
    RightTrigger = property(get_RightTrigger, put_RightTrigger)
class IInjectedInputGamepadInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfoFactory'
    _iid_ = Guid('{59596876-6c39-4ec4-8b2a-29ef7de18aca}')
    @winrt_commethod(6)
    def CreateInstanceFromGamepadReading(self, reading: win32more.Windows.Gaming.Input.GamepadReading) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo: ...
class IInjectedInputKeyboardInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo'
    _iid_ = Guid('{4b46d140-2b6a-5ffa-7eae-bd077b052acd}')
    @winrt_commethod(6)
    def get_KeyOptions(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyOptions: ...
    @winrt_commethod(7)
    def put_KeyOptions(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyOptions) -> Void: ...
    @winrt_commethod(8)
    def get_ScanCode(self) -> UInt16: ...
    @winrt_commethod(9)
    def put_ScanCode(self, value: UInt16) -> Void: ...
    @winrt_commethod(10)
    def get_VirtualKey(self) -> UInt16: ...
    @winrt_commethod(11)
    def put_VirtualKey(self, value: UInt16) -> Void: ...
    KeyOptions = property(get_KeyOptions, put_KeyOptions)
    ScanCode = property(get_ScanCode, put_ScanCode)
    VirtualKey = property(get_VirtualKey, put_VirtualKey)
class IInjectedInputMouseInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo'
    _iid_ = Guid('{96f56e6b-e47a-5cf4-418d-8a5fb9670c7d}')
    @winrt_commethod(6)
    def get_MouseOptions(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseOptions: ...
    @winrt_commethod(7)
    def put_MouseOptions(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseOptions) -> Void: ...
    @winrt_commethod(8)
    def get_MouseData(self) -> UInt32: ...
    @winrt_commethod(9)
    def put_MouseData(self, value: UInt32) -> Void: ...
    @winrt_commethod(10)
    def get_DeltaY(self) -> Int32: ...
    @winrt_commethod(11)
    def put_DeltaY(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_DeltaX(self) -> Int32: ...
    @winrt_commethod(13)
    def put_DeltaX(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_TimeOffsetInMilliseconds(self) -> UInt32: ...
    @winrt_commethod(15)
    def put_TimeOffsetInMilliseconds(self, value: UInt32) -> Void: ...
    DeltaX = property(get_DeltaX, put_DeltaX)
    DeltaY = property(get_DeltaY, put_DeltaY)
    MouseData = property(get_MouseData, put_MouseData)
    MouseOptions = property(get_MouseOptions, put_MouseOptions)
    TimeOffsetInMilliseconds = property(get_TimeOffsetInMilliseconds, put_TimeOffsetInMilliseconds)
class IInjectedInputPenInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo'
    _iid_ = Guid('{6b40ad03-ca1e-5527-7e02-2828540bb1d4}')
    @winrt_commethod(6)
    def get_PointerInfo(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo: ...
    @winrt_commethod(7)
    def put_PointerInfo(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo) -> Void: ...
    @winrt_commethod(8)
    def get_PenButtons(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenButtons: ...
    @winrt_commethod(9)
    def put_PenButtons(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenButtons) -> Void: ...
    @winrt_commethod(10)
    def get_PenParameters(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenParameters: ...
    @winrt_commethod(11)
    def put_PenParameters(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenParameters) -> Void: ...
    @winrt_commethod(12)
    def get_Pressure(self) -> Double: ...
    @winrt_commethod(13)
    def put_Pressure(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_Rotation(self) -> Double: ...
    @winrt_commethod(15)
    def put_Rotation(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_TiltX(self) -> Int32: ...
    @winrt_commethod(17)
    def put_TiltX(self, value: Int32) -> Void: ...
    @winrt_commethod(18)
    def get_TiltY(self) -> Int32: ...
    @winrt_commethod(19)
    def put_TiltY(self, value: Int32) -> Void: ...
    PenButtons = property(get_PenButtons, put_PenButtons)
    PenParameters = property(get_PenParameters, put_PenParameters)
    PointerInfo = property(get_PointerInfo, put_PointerInfo)
    Pressure = property(get_Pressure, put_Pressure)
    Rotation = property(get_Rotation, put_Rotation)
    TiltX = property(get_TiltX, put_TiltX)
    TiltY = property(get_TiltY, put_TiltY)
class IInjectedInputTouchInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo'
    _iid_ = Guid('{224fd1df-43e8-5ef5-510a-69ca8c9b4c28}')
    @winrt_commethod(6)
    def get_Contact(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputRectangle: ...
    @winrt_commethod(7)
    def put_Contact(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputRectangle) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> Int32: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_PointerInfo(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo: ...
    @winrt_commethod(11)
    def put_PointerInfo(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo) -> Void: ...
    @winrt_commethod(12)
    def get_Pressure(self) -> Double: ...
    @winrt_commethod(13)
    def put_Pressure(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_TouchParameters(self) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchParameters: ...
    @winrt_commethod(15)
    def put_TouchParameters(self, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchParameters) -> Void: ...
    Contact = property(get_Contact, put_Contact)
    Orientation = property(get_Orientation, put_Orientation)
    PointerInfo = property(get_PointerInfo, put_PointerInfo)
    Pressure = property(get_Pressure, put_Pressure)
    TouchParameters = property(get_TouchParameters, put_TouchParameters)
class IInputInjector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInputInjector'
    _iid_ = Guid('{8ec26f84-0b02-4bd2-ad7a-3d4658be3e18}')
    @winrt_commethod(6)
    def InjectKeyboardInput(self, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyboardInfo]) -> Void: ...
    @winrt_commethod(7)
    def InjectMouseInput(self, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseInfo]) -> Void: ...
    @winrt_commethod(8)
    def InitializeTouchInjection(self, visualMode: win32more.Windows.UI.Input.Preview.Injection.InjectedInputVisualizationMode) -> Void: ...
    @winrt_commethod(9)
    def InjectTouchInput(self, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchInfo]) -> Void: ...
    @winrt_commethod(10)
    def UninitializeTouchInjection(self) -> Void: ...
    @winrt_commethod(11)
    def InitializePenInjection(self, visualMode: win32more.Windows.UI.Input.Preview.Injection.InjectedInputVisualizationMode) -> Void: ...
    @winrt_commethod(12)
    def InjectPenInput(self, input: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenInfo) -> Void: ...
    @winrt_commethod(13)
    def UninitializePenInjection(self) -> Void: ...
    @winrt_commethod(14)
    def InjectShortcut(self, shortcut: win32more.Windows.UI.Input.Preview.Injection.InjectedInputShortcut) -> Void: ...
class IInputInjector2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInputInjector2'
    _iid_ = Guid('{8e7a905d-1453-43a7-9bcb-06d6d7b305f7}')
    @winrt_commethod(6)
    def InitializeGamepadInjection(self) -> Void: ...
    @winrt_commethod(7)
    def InjectGamepadInput(self, input: win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo) -> Void: ...
    @winrt_commethod(8)
    def UninitializeGamepadInjection(self) -> Void: ...
class IInputInjectorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInputInjectorStatics'
    _iid_ = Guid('{deae6943-7402-4141-a5c6-0c01aa57b16a}')
    @winrt_commethod(6)
    def TryCreate(self) -> win32more.Windows.UI.Input.Preview.Injection.InputInjector: ...
class IInputInjectorStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.Injection.IInputInjectorStatics2'
    _iid_ = Guid('{a4db38fb-dd8c-414f-95ea-f87ef4c0ae6c}')
    @winrt_commethod(6)
    def TryCreateForAppBroadcastOnly(self) -> win32more.Windows.UI.Input.Preview.Injection.InputInjector: ...
class InjectedInputButtonChangeKind(Enum, Int32):
    None_ = 0
    FirstButtonDown = 1
    FirstButtonUp = 2
    SecondButtonDown = 3
    SecondButtonUp = 4
    ThirdButtonDown = 5
    ThirdButtonUp = 6
    FourthButtonDown = 7
    FourthButtonUp = 8
    FifthButtonDown = 9
    FifthButtonUp = 10
class InjectedInputGamepadInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo
    _classid_ = 'Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo.CreateInstanceFromGamepadReading(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo: ...
    @winrt_factorymethod
    def CreateInstanceFromGamepadReading(cls: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfoFactory, reading: win32more.Windows.Gaming.Input.GamepadReading) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo: ...
    @winrt_mixinmethod
    def get_Buttons(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> win32more.Windows.Gaming.Input.GamepadButtons: ...
    @winrt_mixinmethod
    def put_Buttons(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: win32more.Windows.Gaming.Input.GamepadButtons) -> Void: ...
    @winrt_mixinmethod
    def get_LeftThumbstickX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_LeftThumbstickX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LeftThumbstickY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_LeftThumbstickY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LeftTrigger(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_LeftTrigger(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RightThumbstickX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_RightThumbstickX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RightThumbstickY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_RightThumbstickY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RightTrigger(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo) -> Double: ...
    @winrt_mixinmethod
    def put_RightTrigger(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputGamepadInfo, value: Double) -> Void: ...
    Buttons = property(get_Buttons, put_Buttons)
    LeftThumbstickX = property(get_LeftThumbstickX, put_LeftThumbstickX)
    LeftThumbstickY = property(get_LeftThumbstickY, put_LeftThumbstickY)
    LeftTrigger = property(get_LeftTrigger, put_LeftTrigger)
    RightThumbstickX = property(get_RightThumbstickX, put_RightThumbstickX)
    RightThumbstickY = property(get_RightThumbstickY, put_RightThumbstickY)
    RightTrigger = property(get_RightTrigger, put_RightTrigger)
class InjectedInputKeyOptions(Enum, UInt32):
    None_ = 0
    ExtendedKey = 1
    KeyUp = 2
    ScanCode = 8
    Unicode = 4
class InjectedInputKeyboardInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo
    _classid_ = 'Windows.UI.Input.Preview.Injection.InjectedInputKeyboardInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyboardInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyboardInfo: ...
    @winrt_mixinmethod
    def get_KeyOptions(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyOptions: ...
    @winrt_mixinmethod
    def put_KeyOptions(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyOptions) -> Void: ...
    @winrt_mixinmethod
    def get_ScanCode(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo) -> UInt16: ...
    @winrt_mixinmethod
    def put_ScanCode(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo, value: UInt16) -> Void: ...
    @winrt_mixinmethod
    def get_VirtualKey(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo) -> UInt16: ...
    @winrt_mixinmethod
    def put_VirtualKey(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputKeyboardInfo, value: UInt16) -> Void: ...
    KeyOptions = property(get_KeyOptions, put_KeyOptions)
    ScanCode = property(get_ScanCode, put_ScanCode)
    VirtualKey = property(get_VirtualKey, put_VirtualKey)
class InjectedInputMouseInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo
    _classid_ = 'Windows.UI.Input.Preview.Injection.InjectedInputMouseInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseInfo: ...
    @winrt_mixinmethod
    def get_MouseOptions(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseOptions: ...
    @winrt_mixinmethod
    def put_MouseOptions(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseOptions) -> Void: ...
    @winrt_mixinmethod
    def get_MouseData(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo) -> UInt32: ...
    @winrt_mixinmethod
    def put_MouseData(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_DeltaY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo) -> Int32: ...
    @winrt_mixinmethod
    def put_DeltaY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_DeltaX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo) -> Int32: ...
    @winrt_mixinmethod
    def put_DeltaX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TimeOffsetInMilliseconds(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo) -> UInt32: ...
    @winrt_mixinmethod
    def put_TimeOffsetInMilliseconds(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputMouseInfo, value: UInt32) -> Void: ...
    DeltaX = property(get_DeltaX, put_DeltaX)
    DeltaY = property(get_DeltaY, put_DeltaY)
    MouseData = property(get_MouseData, put_MouseData)
    MouseOptions = property(get_MouseOptions, put_MouseOptions)
    TimeOffsetInMilliseconds = property(get_TimeOffsetInMilliseconds, put_TimeOffsetInMilliseconds)
class InjectedInputMouseOptions(Enum, UInt32):
    None_ = 0
    Move = 1
    LeftDown = 2
    LeftUp = 4
    RightDown = 8
    RightUp = 16
    MiddleDown = 32
    MiddleUp = 64
    XDown = 128
    XUp = 256
    Wheel = 2048
    HWheel = 4096
    MoveNoCoalesce = 8192
    VirtualDesk = 16384
    Absolute = 32768
class InjectedInputPenButtons(Enum, UInt32):
    None_ = 0
    Barrel = 1
    Inverted = 2
    Eraser = 4
class InjectedInputPenInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo
    _classid_ = 'Windows.UI.Input.Preview.Injection.InjectedInputPenInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenInfo: ...
    @winrt_mixinmethod
    def get_PointerInfo(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo: ...
    @winrt_mixinmethod
    def put_PointerInfo(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo) -> Void: ...
    @winrt_mixinmethod
    def get_PenButtons(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenButtons: ...
    @winrt_mixinmethod
    def put_PenButtons(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenButtons) -> Void: ...
    @winrt_mixinmethod
    def get_PenParameters(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenParameters: ...
    @winrt_mixinmethod
    def put_PenParameters(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenParameters) -> Void: ...
    @winrt_mixinmethod
    def get_Pressure(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> Double: ...
    @winrt_mixinmethod
    def put_Pressure(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Rotation(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> Double: ...
    @winrt_mixinmethod
    def put_Rotation(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TiltX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> Int32: ...
    @winrt_mixinmethod
    def put_TiltX(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TiltY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo) -> Int32: ...
    @winrt_mixinmethod
    def put_TiltY(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputPenInfo, value: Int32) -> Void: ...
    PenButtons = property(get_PenButtons, put_PenButtons)
    PenParameters = property(get_PenParameters, put_PenParameters)
    PointerInfo = property(get_PointerInfo, put_PointerInfo)
    Pressure = property(get_Pressure, put_Pressure)
    Rotation = property(get_Rotation, put_Rotation)
    TiltX = property(get_TiltX, put_TiltX)
    TiltY = property(get_TiltY, put_TiltY)
class InjectedInputPenParameters(Enum, UInt32):
    None_ = 0
    Pressure = 1
    Rotation = 2
    TiltX = 4
    TiltY = 8
class InjectedInputPoint(Structure):
    PositionX: Int32
    PositionY: Int32
class InjectedInputPointerInfo(Structure):
    PointerId: UInt32
    PointerOptions: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerOptions
    PixelLocation: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPoint
    TimeOffsetInMilliseconds: UInt32
    PerformanceCount: UInt64
class InjectedInputPointerOptions(Enum, UInt32):
    None_ = 0
    New = 1
    InRange = 2
    InContact = 4
    FirstButton = 16
    SecondButton = 32
    Primary = 8192
    Confidence = 16384
    Canceled = 32768
    PointerDown = 65536
    Update = 131072
    PointerUp = 262144
    CaptureChanged = 2097152
class InjectedInputRectangle(Structure):
    Left: Int32
    Top: Int32
    Bottom: Int32
    Right: Int32
class InjectedInputShortcut(Enum, Int32):
    Back = 0
    Start = 1
    Search = 2
class InjectedInputTouchInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo
    _classid_ = 'Windows.UI.Input.Preview.Injection.InjectedInputTouchInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchInfo: ...
    @winrt_mixinmethod
    def get_Contact(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputRectangle: ...
    @winrt_mixinmethod
    def put_Contact(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputRectangle) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo) -> Int32: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_PointerInfo(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo: ...
    @winrt_mixinmethod
    def put_PointerInfo(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPointerInfo) -> Void: ...
    @winrt_mixinmethod
    def get_Pressure(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo) -> Double: ...
    @winrt_mixinmethod
    def put_Pressure(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TouchParameters(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo) -> win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchParameters: ...
    @winrt_mixinmethod
    def put_TouchParameters(self: win32more.Windows.UI.Input.Preview.Injection.IInjectedInputTouchInfo, value: win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchParameters) -> Void: ...
    Contact = property(get_Contact, put_Contact)
    Orientation = property(get_Orientation, put_Orientation)
    PointerInfo = property(get_PointerInfo, put_PointerInfo)
    Pressure = property(get_Pressure, put_Pressure)
    TouchParameters = property(get_TouchParameters, put_TouchParameters)
class InjectedInputTouchParameters(Enum, UInt32):
    None_ = 0
    Contact = 1
    Orientation = 2
    Pressure = 4
class InjectedInputVisualizationMode(Enum, Int32):
    None_ = 0
    Default = 1
    Indirect = 2
class InputInjector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Preview.Injection.IInputInjector
    _classid_ = 'Windows.UI.Input.Preview.Injection.InputInjector'
    @winrt_mixinmethod
    def InjectKeyboardInput(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputKeyboardInfo]) -> Void: ...
    @winrt_mixinmethod
    def InjectMouseInput(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputMouseInfo]) -> Void: ...
    @winrt_mixinmethod
    def InitializeTouchInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, visualMode: win32more.Windows.UI.Input.Preview.Injection.InjectedInputVisualizationMode) -> Void: ...
    @winrt_mixinmethod
    def InjectTouchInput(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, input: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Input.Preview.Injection.InjectedInputTouchInfo]) -> Void: ...
    @winrt_mixinmethod
    def UninitializeTouchInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector) -> Void: ...
    @winrt_mixinmethod
    def InitializePenInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, visualMode: win32more.Windows.UI.Input.Preview.Injection.InjectedInputVisualizationMode) -> Void: ...
    @winrt_mixinmethod
    def InjectPenInput(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, input: win32more.Windows.UI.Input.Preview.Injection.InjectedInputPenInfo) -> Void: ...
    @winrt_mixinmethod
    def UninitializePenInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector) -> Void: ...
    @winrt_mixinmethod
    def InjectShortcut(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector, shortcut: win32more.Windows.UI.Input.Preview.Injection.InjectedInputShortcut) -> Void: ...
    @winrt_mixinmethod
    def InitializeGamepadInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector2) -> Void: ...
    @winrt_mixinmethod
    def InjectGamepadInput(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector2, input: win32more.Windows.UI.Input.Preview.Injection.InjectedInputGamepadInfo) -> Void: ...
    @winrt_mixinmethod
    def UninitializeGamepadInjection(self: win32more.Windows.UI.Input.Preview.Injection.IInputInjector2) -> Void: ...
    @winrt_classmethod
    def TryCreateForAppBroadcastOnly(cls: win32more.Windows.UI.Input.Preview.Injection.IInputInjectorStatics2) -> win32more.Windows.UI.Input.Preview.Injection.InputInjector: ...
    @winrt_classmethod
    def TryCreate(cls: win32more.Windows.UI.Input.Preview.Injection.IInputInjectorStatics) -> win32more.Windows.UI.Input.Preview.Injection.InputInjector: ...


make_ready(__name__)



import importlib
import xml.etree.ElementTree as ET

from win32more import FAILED, WinError
from win32more._winrt import ComClass, WinRT_String, event_setter
from win32more.asyncui import async_start_runner
from win32more.mddbootstrap import (
    WINDOWSAPPSDK_RELEASE_MAJORMINOR,
    WINDOWSAPPSDK_RELEASE_VERSION_SHORTTAG_W,
    WINDOWSAPPSDK_RUNTIME_VERSION_UINT64,
    MddBootstrapInitialize2,
    MddBootstrapInitializeOptions_OnNoMatch_ShowUI,
    MddBootstrapShutdown,
)
from win32more.Microsoft.UI.Xaml import Application, FrameworkElement, IApplicationOverrides, Window
from win32more.Microsoft.UI.Xaml.Controls import XamlControlsResources
from win32more.Microsoft.UI.Xaml.Markup import IXamlMetadataProvider, XamlReader
from win32more.Microsoft.UI.Xaml.XamlTypeInfo import XamlControlsXamlMetaDataProvider
from win32more.Windows.Win32.Storage.Packaging.Appx import PACKAGE_VERSION
from win32more.Windows.Win32.System.Com import COINIT_APARTMENTTHREADED, CoInitializeEx, CoUninitialize
from win32more.Windows.Win32.UI.HiDpi import DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2, SetProcessDpiAwarenessContext


class XamlApplication(ComClass, Application, IApplicationOverrides, IXamlMetadataProvider):
    def __init__(self):
        XamlApplication.__current = self
        self._OnLaunched_wrapped = self.OnLaunched
        self.OnLaunched = self._OnLaunched_wrapper
        super().__init__(own=True)
        self._provider = XamlControlsXamlMetaDataProvider()

    def _OnLaunched_wrapper(self, args):
        self.Resources.MergedDictionaries.Append(XamlControlsResources())
        self._OnLaunched_wrapped(args)

    def OnLaunched(self, args):
        # You should override this in your devired class
        ...

    def GetXamlType(self, type):
        return self._provider.GetXamlType(type)

    def GetXamlTypeByFullName(self, fullName):
        return self._provider.GetXamlTypeByFullName(fullName)

    def GetXmlnsDefinitions(self):
        return self._provider.GetXmlnsDefinitions()

    __current = None

    @classmethod
    def Start(cls, init):
        r = SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2)
        if not r:
            raise WinError()

        hr = CoInitializeEx(None, COINIT_APARTMENTTHREADED)
        if FAILED(hr):
            raise WinError(hr)

        hr = MddBootstrapInitialize2(
            WINDOWSAPPSDK_RELEASE_MAJORMINOR,
            WINDOWSAPPSDK_RELEASE_VERSION_SHORTTAG_W,
            PACKAGE_VERSION(Version=WINDOWSAPPSDK_RUNTIME_VERSION_UINT64),
            MddBootstrapInitializeOptions_OnNoMatch_ShowUI,
        )
        if FAILED(hr):
            raise WinError(hr)

        async_start_runner()

        Application.Start(lambda params: init())

        # FIXME: force Release() to avoid exit with error code.
        if XamlApplication.__current is not None:
            XamlApplication.__current.Release()

        MddBootstrapShutdown()

        CoUninitialize()

    def LoadXamlAndSetEventHandler(self, xaml):
        uiroot = XamlReader.Load(xaml)
        XamlEventWiring().execute(self, uiroot, xaml)
        return uiroot


class XamlEventWiring:
    def execute(self, app, uiroot, xaml):
        uiroot = self.cast_to_runtime_class(uiroot)

        if isinstance(uiroot, Window):
            window = uiroot
            framework_element = uiroot.Content.as_(FrameworkElement)
        else:
            window = None
            framework_element = uiroot.as_(FrameworkElement)

        xmlroot = ET.fromstring(xaml)
        for xmlelement in xmlroot.iter():
            if xmlelement.tag == "{http://schemas.microsoft.com/winfx/2006/xaml/presentation}Window":
                if window is not None:
                    self.wire_event(app, window, xmlelement)
            else:
                try:
                    name = xmlelement.attrib["{http://schemas.microsoft.com/winfx/2006/xaml}Name"]
                except KeyError:
                    continue
                uielement = self.cast_to_runtime_class(framework_element.FindName(name))
                self.wire_event(app, uielement, xmlelement)

    def wire_event(self, app, uielement, xmlelement):
        for k, v in xmlelement.items():
            if isinstance(getattr(uielement, k, None), event_setter):
                setter = getattr(uielement, k)
                setter += getattr(app, v)

    def cast_to_runtime_class(self, uielement):
        return uielement.as_(self.get_runtime_class(uielement))

    def get_runtime_class(self, uielement):
        namespace, name = self.get_runtime_class_name(uielement).rsplit(".", 1)
        module = importlib.import_module(f"win32more.{namespace}")
        return getattr(module, name)

    def get_runtime_class_name(self, uielement):
        s = WinRT_String(own=True)
        hr = uielement.GetRuntimeClassName(s)
        if FAILED(hr):
            raise WinError(hr)
        return s.strvalue



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.InternetConnectionWizard
ICW_REGPATHSETTINGS: String = 'Software\\Microsoft\\Internet Connection Wizard'
ICW_REGKEYCOMPLETED: String = 'Completed'
ICW_MAX_ACCTNAME: UInt32 = 256
ICW_MAX_PASSWORD: UInt32 = 256
ICW_MAX_LOGONNAME: UInt32 = 256
ICW_MAX_SERVERNAME: UInt32 = 64
ICW_MAX_RASNAME: UInt32 = 256
ICW_MAX_EMAILNAME: UInt32 = 64
ICW_MAX_EMAILADDR: UInt32 = 128
ICW_CHECKSTATUS: UInt32 = 1
ICW_LAUNCHFULL: UInt32 = 256
ICW_LAUNCHMANUAL: UInt32 = 512
ICW_USE_SHELLNEXT: UInt32 = 1024
ICW_FULL_SMARTSTART: UInt32 = 2048
ICW_FULLPRESENT: UInt32 = 1
ICW_MANUALPRESENT: UInt32 = 2
ICW_ALREADYRUN: UInt32 = 4
ICW_LAUNCHEDFULL: UInt32 = 256
ICW_LAUNCHEDMANUAL: UInt32 = 512
ICW_USEDEFAULTS: UInt32 = 1
@winfunctype_pointer
def PFNCHECKCONNECTIONWIZARD(param0: UInt32, param1: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PFNSETSHELLNEXT(param0: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
import win32more.Windows.Win32.UI.Xaml.Diagnostics
E_UNKNOWNTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144665560
@winfunctype('Windows.UI.Xaml.dll')
def InitializeXamlDiagnostic(endPointName: win32more.Windows.Win32.Foundation.PWSTR, pid: UInt32, wszDllXamlDiagnostics: win32more.Windows.Win32.Foundation.PWSTR, wszTAPDllName: win32more.Windows.Win32.Foundation.PWSTR, tapClsid: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('Windows.UI.Xaml.dll')
def InitializeXamlDiagnosticsEx(endPointName: win32more.Windows.Win32.Foundation.PWSTR, pid: UInt32, wszDllXamlDiagnostics: win32more.Windows.Win32.Foundation.PWSTR, wszTAPDllName: win32more.Windows.Win32.Foundation.PWSTR, tapClsid: Guid, wszInitializationData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
BaseValueSource = Int32
BaseValueSourceUnknown: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 0
BaseValueSourceDefault: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 1
BaseValueSourceBuiltInStyle: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 2
BaseValueSourceStyle: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 3
BaseValueSourceLocal: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 4
Inherited: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 5
DefaultStyleTrigger: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 6
TemplateTrigger: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 7
StyleTrigger: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 8
ImplicitStyleReference: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 9
ParentTemplate: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 10
ParentTemplateTrigger: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 11
Animation: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 12
Coercion: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 13
BaseValueSourceVisualState: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource = 14
class BitmapDescription(Structure):
    Width: UInt32
    Height: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    AlphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE
class CollectionElementValue(Structure):
    Index: UInt32
    ValueType: win32more.Windows.Win32.Foundation.BSTR
    Value: win32more.Windows.Win32.Foundation.BSTR
    MetadataBits: Int64
class EnumType(Structure):
    Name: win32more.Windows.Win32.Foundation.BSTR
    ValueInts: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)
    ValueStrings: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)
class IBitmapData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d1a34ef2-cad8-4635-a3d2-fcda8d3f3caf}')
    @commethod(3)
    def CopyBytesTo(self, sourceOffsetInBytes: UInt32, maxBytesToCopy: UInt32, pvBytes: POINTER(Byte), numberOfBytesCopied: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStride(self, pStride: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetBitmapDescription(self, pBitmapDescription: POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.BitmapDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSourceBitmapDescription(self, pBitmapDescription: POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.BitmapDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualTreeService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a593b11a-d17f-48bb-8f66-83910731c8a5}')
    @commethod(3)
    def AdviseVisualTreeChange(self, pCallback: win32more.Windows.Win32.UI.Xaml.Diagnostics.IVisualTreeServiceCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnadviseVisualTreeChange(self, pCallback: win32more.Windows.Win32.UI.Xaml.Diagnostics.IVisualTreeServiceCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnums(self, pCount: POINTER(UInt32), ppEnums: POINTER(POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.EnumType))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateInstance(self, typeName: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.Foundation.BSTR, pInstanceHandle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetPropertyValuesChain(self, instanceHandle: UInt64, pSourceCount: POINTER(UInt32), ppPropertySources: POINTER(POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.PropertyChainSource)), pPropertyCount: POINTER(UInt32), ppPropertyValues: POINTER(POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.PropertyChainValue))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetProperty(self, instanceHandle: UInt64, value: UInt64, propertyIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ClearProperty(self, instanceHandle: UInt64, propertyIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetCollectionCount(self, instanceHandle: UInt64, pCollectionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCollectionElements(self, instanceHandle: UInt64, startIndex: UInt32, pElementCount: POINTER(UInt32), ppElementValues: POINTER(POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.CollectionElementValue))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AddChild(self, parent: UInt64, child: UInt64, index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def RemoveChild(self, parent: UInt64, index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ClearChildren(self, parent: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualTreeService2(ComPtr):
    extends: win32more.Windows.Win32.UI.Xaml.Diagnostics.IVisualTreeService
    _iid_ = Guid('{130f5136-ec43-4f61-89c7-9801a36d2e95}')
    @commethod(15)
    def GetPropertyIndex(self, object: UInt64, propertyName: win32more.Windows.Win32.Foundation.PWSTR, pPropertyIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetProperty(self, object: UInt64, propertyIndex: UInt32, pValue: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReplaceResource(self, resourceDictionary: UInt64, key: UInt64, newValue: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def RenderTargetBitmap(self, handle: UInt64, options: win32more.Windows.Win32.UI.Xaml.Diagnostics.RenderTargetBitmapOptions, maxPixelWidth: UInt32, maxPixelHeight: UInt32, ppBitmapData: POINTER(win32more.Windows.Win32.UI.Xaml.Diagnostics.IBitmapData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualTreeService3(ComPtr):
    extends: win32more.Windows.Win32.UI.Xaml.Diagnostics.IVisualTreeService2
    _iid_ = Guid('{0e79c6e0-85a0-4be8-b41a-655cf1fd19bd}')
    @commethod(19)
    def ResolveResource(self, resourceContext: UInt64, resourceName: win32more.Windows.Win32.Foundation.PWSTR, resourceType: win32more.Windows.Win32.UI.Xaml.Diagnostics.ResourceType, propertyIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetDictionaryItem(self, dictionaryHandle: UInt64, resourceName: win32more.Windows.Win32.Foundation.PWSTR, resourceIsImplicitStyle: win32more.Windows.Win32.Foundation.BOOL, resourceHandle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def AddDictionaryItem(self, dictionaryHandle: UInt64, resourceKey: UInt64, resourceHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def RemoveDictionaryItem(self, dictionaryHandle: UInt64, resourceKey: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualTreeServiceCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aa7a8931-80e4-4fec-8f3b-553f87b4966e}')
    @commethod(3)
    def OnVisualTreeChange(self, relation: win32more.Windows.Win32.UI.Xaml.Diagnostics.ParentChildRelation, element: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualElement, mutationType: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualMutationType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVisualTreeServiceCallback2(ComPtr):
    extends: win32more.Windows.Win32.UI.Xaml.Diagnostics.IVisualTreeServiceCallback
    _iid_ = Guid('{bad9eb88-ae77-4397-b948-5fa2db0a19ea}')
    @commethod(4)
    def OnElementStateChanged(self, element: UInt64, elementState: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualElementState, context: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXamlDiagnostics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{18c9e2b6-3f43-4116-9f2b-ff935d7770d2}')
    @commethod(3)
    def GetDispatcher(self, ppDispatcher: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUiLayer(self, ppLayer: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetApplication(self, ppApplication: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIInspectableFromHandle(self, instanceHandle: UInt64, ppInstance: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetHandleFromIInspectable(self, pInstance: win32more.Windows.Win32.System.WinRT.IInspectable, pHandle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def HitTest(self, rect: win32more.Windows.Win32.Foundation.RECT, pCount: POINTER(UInt32), ppInstanceHandles: POINTER(POINTER(UInt64))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RegisterInstance(self, pInstance: win32more.Windows.Win32.System.WinRT.IInspectable, pInstanceHandle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetInitializationData(self, pInitializationData: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class MetadataBit(Enum, Int32):
    None_ = 0
    IsValueHandle = 1
    IsPropertyReadOnly = 2
    IsValueCollection = 4
    IsValueCollectionReadOnly = 8
    IsValueBindingExpression = 16
    IsValueNull = 32
    IsValueHandleAndEvaluatedValue = 64
class ParentChildRelation(Structure):
    Parent: UInt64
    Child: UInt64
    ChildIndex: UInt32
class PropertyChainSource(Structure):
    Handle: UInt64
    TargetType: win32more.Windows.Win32.Foundation.BSTR
    Name: win32more.Windows.Win32.Foundation.BSTR
    Source: win32more.Windows.Win32.UI.Xaml.Diagnostics.BaseValueSource
    SrcInfo: win32more.Windows.Win32.UI.Xaml.Diagnostics.SourceInfo
class PropertyChainValue(Structure):
    Index: UInt32
    Type: win32more.Windows.Win32.Foundation.BSTR
    DeclaringType: win32more.Windows.Win32.Foundation.BSTR
    ValueType: win32more.Windows.Win32.Foundation.BSTR
    ItemType: win32more.Windows.Win32.Foundation.BSTR
    Value: win32more.Windows.Win32.Foundation.BSTR
    Overridden: win32more.Windows.Win32.Foundation.BOOL
    MetadataBits: Int64
    PropertyName: win32more.Windows.Win32.Foundation.BSTR
    PropertyChainIndex: UInt32
RenderTargetBitmapOptions = Int32
RenderTarget: win32more.Windows.Win32.UI.Xaml.Diagnostics.RenderTargetBitmapOptions = 0
RenderTargetAndChildren: win32more.Windows.Win32.UI.Xaml.Diagnostics.RenderTargetBitmapOptions = 1
ResourceType = Int32
ResourceTypeStatic: win32more.Windows.Win32.UI.Xaml.Diagnostics.ResourceType = 0
ResourceTypeTheme: win32more.Windows.Win32.UI.Xaml.Diagnostics.ResourceType = 1
class SourceInfo(Structure):
    FileName: win32more.Windows.Win32.Foundation.BSTR
    LineNumber: UInt32
    ColumnNumber: UInt32
    CharPosition: UInt32
    Hash: win32more.Windows.Win32.Foundation.BSTR
class VisualElement(Structure):
    Handle: UInt64
    SrcInfo: win32more.Windows.Win32.UI.Xaml.Diagnostics.SourceInfo
    Type: win32more.Windows.Win32.Foundation.BSTR
    Name: win32more.Windows.Win32.Foundation.BSTR
    NumChildren: UInt32
VisualElementState = Int32
ErrorResolved: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualElementState = 0
ErrorResourceNotFound: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualElementState = 1
ErrorInvalidResource: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualElementState = 2
VisualMutationType = Int32
Add: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualMutationType = 0
Remove: win32more.Windows.Win32.UI.Xaml.Diagnostics.VisualMutationType = 1


make_ready(__name__)
